/*
 *
 *    This file is a part of Space Geodetic Library. The library is used by
 *    nuSolve, a part of CALC/SOLVE system, and designed to make analysis of
 *    geodetic VLBI observations.
 *    Copyright (C) 2010-2020 Sergei Bolotin.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */



#include <SgTidalUt1.h>


/*=====================================================================================================*/
//
// constants:
//
/*=====================================================================================================*/
const SgUt1TidalTableEntry_Simplified  ut1Ttable_Ut1cm[] = 
{
  // this is `cut-and-copy' from ut1cm.f:
  //
  //  TABLE OF MULTIPLES OF ARGUMENTS AND COEFFICIENTS
  //
  //    MULTIPLE OF             DUT         DLOD   DOMEGA
  // L   L'  F   D OMEGA   COEFF. OF SIN    COEFF. OF COS
  {{ 1,  0,  2,  2,  2},      -0.02,        0.3,    -0.2},
  {{ 2,  0,  2,  0,  1},      -0.04,        0.4,    -0.3},
  {{ 2,  0,  2,  0,  2},      -0.10,        0.9,    -0.8},
  {{ 0,  0,  2,  2,  1},      -0.05,        0.4,    -0.4},
  {{ 0,  0,  2,  2,  2},      -0.12,        1.1,    -0.9},
  //
  {{ 1,  0,  2,  0,  0},      -0.04,        0.3,    -0.2},
  {{ 1,  0,  2,  0,  1},      -0.41,        2.8,    -2.4},
  {{ 1,  0,  2,  0,  2},      -0.99,        6.8,    -5.8},
  {{ 3,  0,  0,  0,  0},      -0.02,        0.1,    -0.1},
  {{-1,  0,  2,  2,  1},      -0.08,        0.5,    -0.5},
  //
  {{-1,  0,  2,  2,  2},      -0.20,        1.3,    -1.1},
  {{ 1,  0,  0,  2,  0},      -0.08,        0.5,    -0.4},
  {{ 2,  0,  2, -2,  2},       0.02,       -0.1,     0.1},
  {{ 0,  1,  2,  0,  2},       0.03,       -0.1,     0.1},
  {{ 0,  0,  2,  0,  0},      -0.30,        1.4,    -1.2},
  //
  {{ 0,  0,  2,  0,  1},      -3.21,       14.8,   -12.5},
  {{ 0,  0,  2,  0,  2},      -7.76,       35.7,   -30.1},
  {{ 2,  0,  0,  0, -1},       0.02,       -0.1,     0.1},
  {{ 2,  0,  0,  0,  0},      -0.34,        1.5,    -1.3},
  {{ 2,  0,  0,  0,  1},       0.02,       -0.1,     0.1},
  //
  {{ 0, -1,  2,  0,  2},      -0.02,        0.1,    -0.1},
  {{ 0,  0,  0,  2, -1},       0.05,       -0.2,     0.2},
  {{ 0,  0,  0,  2,  0},      -0.73,        3.1,    -2.6},
  {{ 0,  0,  0,  2,  1},      -0.05,        0.2,    -0.2},
  {{ 0, -1,  0,  2,  0},      -0.05,        0.2,    -0.2},
  //
  {{ 1,  0,  2, -2,  1},       0.05,       -0.1,     0.1},
  {{ 1,  0,  2, -2,  2},       0.10,       -0.3,     0.2},
  {{ 1,  1,  0,  0,  0},       0.04,       -0.1,     0.1},
  {{-1,  0,  2,  0,  0},       0.05,       -0.1,     0.1},
  {{-1,  0,  2,  0,  1},       0.18,       -0.4,     0.3},
  //
  {{-1,  0,  2,  0,  2},       0.44,       -1.0,     0.9},
  {{ 1,  0,  0,  0, -1},       0.53,       -1.2,     1.0},
  {{ 1,  0,  0,  0,  0},      -8.26,       18.8,   -15.9},
  {{ 1,  0,  0,  0,  1},       0.54,       -1.2,     1.0},
  {{ 0,  0,  0,  1,  0},       0.05,       -0.1,     0.1},
  //
  {{ 1, -1,  0,  0,  0},      -0.06,        0.1,    -0.1},
  {{-1,  0,  0,  2, -1},       0.12,       -0.2,     0.2},
  {{-1,  0,  0,  2,  0},      -1.82,        3.6,    -3.0},
  {{-1,  0,  0,  2,  1},       0.13,       -0.3,     0.2},
  {{ 1,  0, -2,  2, -1},       0.02,        0.0,     0.0},
  //
  {{-1, -1,  0,  2,  0},      -0.09,        0.2,    -0.1},
};
const int numOfRecs_Ut1cm = sizeof(ut1Ttable_Ut1cm)/sizeof(SgUt1TidalTableEntry_Simplified);




const SgUt1TidalTableEntry_Standard ut1Ttable_Ut1s2k[] = 
{
  //his is `cut-and-copy' from ut1s2k.f:
  //  Multiple of                 DUT          DLOD         DOMEGA
  // l   l'  F   D OMEGA      sin    cos     cos   sin      cos   sin
  {{ 1,  0,  2,  2,  2},     -0.02,  0.00,   0.26, 0.00,   -0.22, .00},
  {{ 2,  0,  2,  0,  1},     -0.04,  0.00,   0.38, 0.00,   -0.32, .00},
  {{ 2,  0,  2,  0,  2},     -0.10,  0.00,   0.91, 0.00,   -0.76, .00},
  {{ 0,  0,  2,  2,  1},     -0.05,  0.00,   0.45, 0.00,   -0.38, .00},
  {{ 0,  0,  2,  2,  2},     -0.12,  0.00,   1.09, 0.01,   -0.92,-.01},
  //
  {{ 1,  0,  2,  0,  0},     -0.04,  0.00,   0.27, 0.00,   -0.22, .0 },
  {{ 1,  0,  2,  0,  1},     -0.40,  0.00,   2.84, 0.02,   -2.40,-.01},
  {{ 1,  0,  2,  0,  2},     -1.00,  0.01,   6.85, 0.04,   -5.78,-.03},
  {{ 3,  0,  0,  0,  0},     -0.02,  0.00,   0.12, 0.00,   -0.11, .00},
  {{-1,  0,  2,  2,  1},     -0.08,  0.00,   0.54, 0.00,   -0.46, .00},
  //
  {{-1,  0,  2,  2,  2},     -0.20,  0.00,   1.30, 0.01,   -1.10,-.01},
  {{ 1,  0,  0,  2,  0},     -0.08,  0.00,   0.50, 0.00,   -0.42, .00},
  {{ 2,  0,  2, -2,  2},      0.02,  0.00,  -0.11, 0.00,    0.09, .00},
  {{ 0,  1,  2,  0,  2},      0.03,  0.00,  -0.12, 0.00,    0.10, .00},
  {{ 0,  0,  2,  0,  0},     -0.30,  0.00,   1.39, 0.01,   -1.17,-.01},
  //
  {{ 0,  0,  2,  0,  1},     -3.22,  0.02,  14.86, 0.09,  -12.54,-.08},
  {{ 0,  0,  2,  0,  2},     -7.79,  0.05,  35.84, 0.22,  -30.25,-.18},
  {{ 2,  0,  0,  0, -1},      0.02,  0.00,  -0.10, 0.00,    0.08, .00},
  {{ 2,  0,  0,  0,  0},     -0.34,  0.00,   1.55, 0.01,   -1.31,-.01},
  {{ 2,  0,  0,  0,  1},      0.02,  0.00,  -0.08, 0.00,    0.07, .00},
  //
  //
  {{ 0, -1,  2,  0,  2},     -0.02,  0.00,   0.11, 0.00,   -0.09, .00},
  {{ 0,  0,  0,  2, -1},      0.05,  0.00,  -0.20, 0.00,    0.17, .00},
  {{ 0,  0,  0,  2,  0},     -0.74,  0.00,   3.14, 0.02,   -2.65,-.02},
  {{ 0,  0,  0,  2,  1},     -0.05,  0.00,   0.22, 0.00,   -0.19, .00},
  {{ 0, -1,  0,  2,  0},     -0.05,  0.00,   0.21, 0.00,   -0.17, .00},
  //
  {{ 1,  0,  2, -2,  1},      0.05,  0.00,  -0.13, 0.00,    0.11, .00},
  {{ 1,  0,  2, -2,  2},      0.10,  0.00,  -0.26, 0.00,    0.22, .00},
  {{ 1,  1,  0,  0,  0},      0.04,  0.00,  -0.10, 0.00,    0.08, .00},
  {{-1,  0,  2,  0,  0},      0.05,  0.00,  -0.11, 0.00,    0.09, .00},
  {{-1,  0,  2,  0,  1},      0.18,  0.00,  -0.41, 0.00,    0.35, .00},
  //
  {{-1,  0,  2,  0,  2},      0.44,  0.00,  -1.02,-0.01,    0.86, .01},
  {{ 1,  0,  0,  0, -1},      0.54,  0.00,  -1.23,-0.01,    1.04, .01},
  {{ 1,  0,  0,  0,  0},     -8.33,  0.06,  18.99, 0.13,  -16.03,-.11},
  {{ 1,  0,  0,  0,  1},      0.55,  0.00,  -1.25,-0.01,    1.05, .01},
  {{ 0,  0,  0,  1,  0},      0.05,  0.00,  -0.11, 0.00,    0.09, .00},
  //
  {{ 1, -1,  0,  0,  0},     -0.06,  0.00,   0.12, 0.00,   -0.10, .00},
  {{-1,  0,  0,  2, -1},      0.12,  0.00,  -0.24, 0.00,    0.20, .00},
  {{-1,  0,  0,  2,  0},     -1.84,  0.01,   3.63, 0.02,   -3.07,-.02},
  {{-1,  0,  0,  2,  1},      0.13,  0.00,  -0.26, 0.00,    0.22, .00},
  {{ 1,  0, -2,  2, -1},      0.02,  0.00,  -0.04, 0.00,    0.03, .03},
  //
  //
  {{-1, -1,  0,  2,  0},     -0.09,  0.00,   0.16, 0.00,   -0.13, .00},
  {{ 0,  2,  2, -2,  2},     -0.06,  0.00,   0.04, 0.00,   -0.03, .00},
  {{ 0,  1,  2, -2,  1},      0.03,  0.00,  -0.02, 0.00,    0.01, .00},
  {{ 0,  1,  2, -2,  2},     -1.91,  0.02,   0.98, 0.01,   -0.83,-.01},
  {{ 0,  0,  2, -2,  0},      0.26,  0.00,  -0.09, 0.00,    0.08, .00},
  //
  {{ 0,  0,  2, -2,  1},      1.18, -0.01,  -0.42, 0.00,    0.35, .00},
  {{ 0,  0,  2, -2,  2},    -49.06,  0.43,  16.88, 0.15,  -14.25,-.13},
  {{ 0,  2,  0,  0,  0},     -0.20,  0.00,   0.07, 0.00,   -0.06, .00},
  {{ 2,  0,  0, -2, -1},      0.05,  0.00,  -0.02, 0.00,    0.01, .00},
  {{ 2,  0,  0, -2,  0},     -0.56,  0.01,   0.17, 0.00,   -0.14, .00},
  //
  {{ 2,  0,  0, -2,  1},      0.04,  0.00,  -0.01, 0.00,    0.01, .00},
  {{ 0, -1,  2, -2,  1},     -0.05,  0.00,   0.01, 0.00,   -0.01, .00},
  {{ 0,  1,  0,  0, -1},      0.09,  0.00,  -0.02, 0.00,    0.01, .00},
  {{ 0, -1,  2, -2,  2},      0.82, -0.01,  -0.14, 0.00,    0.12, .00},
  {{ 0,  1,  0,  0,  0},    -15.65,  0.15,   2.69, 0.03,   -2.27,-.02},
  //
  {{ 0,  1,  0,  0,  1},     -0.14,  0.00,   0.02, 0.00,   -0.02, .00},
  {{ 1,  0,  0, -1,  0},      0.03,  0.00,   0.00, 0.00,    0.0 , .00},
  {{ 2,  0, -2,  0,  0},     -0.14,  0.00,  -0.01, 0.00,    0.01, .00},
  {{-2,  0,  2,  0,  1},      0.43, -0.01,  -0.02, 0.00,    0.02, .00},
  {{-1,  1,  0,  1,  0},     -0.04,  0.00,   0.00, 0.00,    0.00, .00},
  //
  //
  {{ 0,  0,  0,  0,  2},      8.20,  0.11,   0.15, 0.00,   -0.13, .00},
  {{ 0,  0,  0,  0,  1},  -1689.54,-25.04, -15.62, 0.23,   13.18,-.20},
};
const int numOfRecs_Ut1s2k = sizeof(ut1Ttable_Ut1s2k)/sizeof(SgUt1TidalTableEntry_Standard);




const SgUt1TidalTableEntry_Standard ut1Ttable_Ut1s82[] = 
{
  //     Table of multiples of arguments and coefficients
  //
  // Multiple of            DUT        DLOD      DOMEGA
  // l  l' F  D OMEGA    sin   cos    cos  sin   cos   sin
  {{ 1, 0, 2, 2, 2},    -0.02, 0.00,  0.3, 0.0, -0.2,  0.0},
  {{ 2, 0, 2, 0, 1},    -0.04, 0.00,  0.4, 0.0, -0.3,  0.0},
  {{ 2, 0, 2, 0, 2},    -0.10, 0.00,  0.9, 0.0, -0.8,  0.0},
  {{ 0, 0, 2, 2, 1},    -0.05, 0.00,  0.4, 0.0, -0.4,  0.0},
  {{ 0, 0, 2, 2, 2},    -0.12, 0.00,  1.1, 0.0, -0.9,  0.0},
  //
  {{ 1, 0, 2, 0, 0},    -0.04, 0.00,  0.3, 0.0, -0.2,  0.0},
  {{ 1, 0, 2, 0, 1},    -0.40, 0.01,  2.7, 0.1, -2.3, -0.1},
  {{ 1, 0, 2, 0, 2},    -0.98, 0.03,  6.7, 0.2, -5.7, -0.2},
  {{ 3, 0, 0, 0, 0},    -0.02, 0.00,  0.1, 0.0, -0.1,  0.0},
  {{-1, 0, 2, 2, 1},    -0.08, 0.00,  0.5, 0.0, -0.5,  0.0},
  //
  {{-1, 0, 2, 2, 2},    -0.20, 0.00,  1.3, 0.0, -1.1,  0.0},
  {{ 1, 0, 0, 2, 0},    -0.08, 0.00,  0.5, 0.0, -0.4,  0.0},
  {{ 2, 0, 2,-2, 2},     0.02, 0.00, -0.1, 0.0,  0.1,  0.0},
  {{ 0, 1, 2, 0, 2},     0.03, 0.00, -0.1, 0.0,  0.1,  0.0},
  {{ 0, 0, 2, 0, 0},    -0.30, 0.00,  1.4, 0.0, -1.2,  0.0},
  //
  {{ 0, 0, 2, 0, 1},    -3.20, 0.09, 14.7, 0.4,-12.4, -0.4},
  {{ 0, 0, 2, 0, 2},    -7.73, 0.21, 35.6, 1.0,-30.0, -0.8},
  {{ 2, 0, 0, 0,-1},     0.02, 0.00, -0.1, 0.0,  0.1,  0.0},
  {{ 2, 0, 0, 0, 0},    -0.34, 0.00,  1.5, 0.0, -1.3,  0.0},
  {{ 2, 0, 0, 0, 1},     0.02, 0.00, -0.1, 0.0,  0.1,  0.0},
  //
  {{ 0,-1, 2, 0, 2},    -0.02, 0.00,  0.1, 0.0, -0.1,  0.0},
  {{ 0, 0, 0, 2,-1},     0.05, 0.00, -0.2, 0.0,  0.2,  0.0},
  {{ 0, 0, 0, 2, 0},    -0.72, 0.02,  3.1, 0.1, -2.6, -0.1},
  {{ 0, 0, 0, 2, 1},    -0.05, 0.00,  0.2, 0.0, -0.2,  0.0},
  {{ 0,-1, 0, 2, 0},    -0.05, 0.00,  0.2, 0.0, -0.2,  0.0},
  //
  {{ 1, 0, 2,-2, 1},     0.05, 0.00, -0.1, 0.0,  0.1,  0.0},
  {{ 1, 0, 2,-2, 2},     0.10, 0.00, -0.3, 0.0,  0.2,  0.0},
  {{ 1, 1, 0, 0, 0},     0.04, 0.00, -0.1, 0.0,  0.1,  0.0},
  {{-1, 0, 2, 0, 0},     0.05, 0.00, -0.1, 0.0,  0.1,  0.0},
  {{-1, 0, 2, 0, 1},     0.18, 0.00, -0.4, 0.0,  0.3,  0.0},
  //
  {{-1, 0, 2, 0, 2},     0.44, 0.00, -1.0, 0.0,  0.9,  0.0},
  {{ 1, 0, 0, 0,-1},     0.53, 0.00, -1.2, 0.0,  1.0,  0.0},
  {{ 1, 0, 0, 0, 0},    -8.33, 0.12, 19.0, 0.3,-16.0, -0.2},
  {{ 1, 0, 0, 0, 1},     0.54, 0.00, -1.2, 0.0,  1.0,  0.0},
  {{ 0, 0, 0, 1, 0},     0.05, 0.00, -0.1, 0.0,  0.1,  0.0},
  //
  {{ 1,-1, 0, 0, 0},    -0.06, 0.00,  0.1, 0.0, -0.1,  0.0},
  {{-1, 0, 0, 2,-1},     0.12, 0.00, -0.2, 0.0,  0.2,  0.0},
  {{-1, 0, 0, 2, 0},    -1.84, 0.02,  3.6, 0.0, -3.0,  0.0},
  {{-1, 0, 0, 2, 1},     0.13, 0.00, -0.3, 0.0,  0.2,  0.0},
  {{ 1, 0,-2, 2,-1},     0.02, 0.00,  0.0, 0.0,  0.0,  0.0},
  //
  {{-1,-1, 0, 2, 0},    -0.09, 0.00,  0.2, 0.0, -0.1,  0.0},
  {{ 0, 2, 2,-2, 2},    -0.06, 0.00,  0.0, 0.0, -0.0,  0.0},
  {{ 0, 1, 2,-2, 1},     0.03, 0.00, -0.0, 0.0,  0.0,  0.0},
  {{ 0, 1, 2,-2, 2},    -1.88, 0.00,  1.0, 0.0, -0.8,  0.0},
  {{ 0, 0, 2,-2, 0},     0.25, 0.00, -0.1, 0.0,  0.1,  0.0},
  //
  {{ 0, 0, 2,-2, 1},     1.17, 0.00, -0.4, 0.0,  0.3,  0.0},
  {{ 0, 0, 2,-2, 2},   -48.84, 0.11, 16.8, 0.0,-14.2,  0.0},
  {{ 0, 2, 0, 0, 0},    -0.19, 0.00,  0.1, 0.0, -0.1,  0.0},
  {{ 2, 0, 0,-2,-1},     0.05, 0.00, -0.0, 0.0,  0.0,  0.0},
  {{ 2, 0, 0,-2, 0},    -0.55, 0.00,  0.2, 0.0, -0.1,  0.0},
  //
  {{ 2, 0, 0,-2, 1},     0.04, 0.00, -0.0, 0.0,  0.0,  0.0},
  {{ 0,-1, 2,-2, 1},    -0.05, 0.00,  0.0, 0.0, -0.0,  0.0},
  {{ 0, 1, 0, 0,-1},     0.09, 0.00, -0.0, 0.0,  0.0,  0.0},
  {{ 0,-1, 2,-2, 2},     0.83, 0.00, -0.1, 0.0,  0.1,  0.0},
  {{ 0, 1, 0, 0, 0},   -15.55, 0.02,  2.6, 0.0, -2.2,  0.0},
  //
  {{ 0, 1, 0, 0, 1},    -0.14, 0.00,  0.0, 0.0, -0.0,  0.0},
  {{ 1, 0, 0,-1, 0},     0.03, 0.00, -0.0, 0.0,  0.0,  0.0},
  {{ 2, 0,-2, 0, 0},    -0.14, 0.00, -0.0, 0.0,  0.0,  0.0},
  {{-2, 0, 2, 0, 1},     0.42, 0.00, -0.0, 0.0,  0.0,  0.0},
  {{-1, 1, 0, 1, 0},     0.04, 0.00, -0.0, 0.0,  0.0,  0.0},
  //
  {{ 0, 0, 0, 0, 2},     7.90, 0.00,  0.1, 0.0, -0.1,  0.0},
  {{ 0, 0, 0, 0, 1}, -1637.68, 0.10,-10.4, 0.0,  8.8,  0.0},
};
const int numOfRecs_Ut1s82 = sizeof(ut1Ttable_Ut1s82)/sizeof(SgUt1TidalTableEntry_Standard);




const SgUt1TidalTableEntry_Clipped     ut1Ttable_Ut1s83[] =
{
  //      Table of multiples of arguments and coefficients
  //
  //                    Multiple of            DUT
  // l   l'  F   D OMEGA     sin   cos
  {{ 1, 0, 2, 2, 2},    -0.02, 0.00},
  {{ 2, 0, 2, 0, 1},    -0.04, 0.00},
  {{ 2, 0, 2, 0, 2},    -0.10, 0.00},
  {{ 0, 0, 2, 2, 1},    -0.05, 0.00},
  {{ 0, 0, 2, 2, 2},    -0.12, 0.00},
  {{ 1, 0, 2, 0, 0},    -0.04, 0.00},
  {{ 1, 0, 2, 0, 1},    -0.40, 0.01},
  {{ 1, 0, 2, 0, 2},    -0.98, 0.03},
  {{ 3, 0, 0, 0, 0},    -0.02, 0.00},
  {{-1, 0, 2, 2, 1},    -0.08, 0.00},
  {{-1, 0, 2, 2, 2},    -0.20, 0.00},
  {{ 1, 0, 0, 2, 0},    -0.08, 0.00},
  {{ 2, 0, 2,-2, 2},     0.02, 0.00},
  {{ 0, 1, 2, 0, 2},     0.03, 0.00},
  {{ 0, 0, 2, 0, 0},    -0.30, 0.00},
  {{ 0, 0, 2, 0, 1},    -3.20, 0.09},
  {{ 0, 0, 2, 0, 2},    -7.73, 0.21},
  {{ 2, 0, 0, 0,-1},     0.02, 0.00},
  {{ 2, 0, 0, 0, 0},    -0.34, 0.00},
  {{ 2, 0, 0, 0, 1},     0.02, 0.00},
  {{ 0,-1, 2, 0, 2},    -0.02, 0.00},
  {{ 0, 0, 0, 2,-1},     0.05, 0.00},
  {{ 0, 0, 0, 2, 0},    -0.72, 0.02},
  {{ 0, 0, 0, 2, 1},    -0.05, 0.00},
  {{ 0,-1, 0, 2, 0},    -0.05, 0.00},
  {{ 1, 0, 2,-2, 1},     0.05, 0.00},
  {{ 1, 0, 2,-2, 2},     0.10, 0.00},
  {{ 1, 1, 0, 0, 0},     0.04, 0.00},
  {{-1, 0, 2, 0, 0},     0.05, 0.00},
  {{-1, 0, 2, 0, 1},     0.18, 0.00},
  {{-1, 0, 2, 0, 2},     0.44, 0.00},
  {{ 1, 0, 0, 0,-1},     0.53, 0.00},
  {{ 1, 0, 0, 0, 0},    -8.33, 0.12},
  {{ 1, 0, 0, 0, 1},     0.54, 0.00},
  {{ 0, 0, 0, 1, 0},     0.05, 0.00},
  {{ 1,-1, 0, 0, 0},    -0.06, 0.00},
  {{-1, 0, 0, 2,-1},     0.12, 0.00},
  {{-1, 0, 0, 2, 0},    -1.84, 0.02},
  {{-1, 0, 0, 2, 1},     0.13, 0.00},
  {{ 1, 0,-2, 2,-1},     0.02, 0.00},
  {{-1,-1, 0, 2, 0},    -0.09, 0.00},
  {{ 0, 2, 2,-2, 2},    -0.06, 0.00},
  {{ 0, 1, 2,-2, 1},     0.03, 0.00},
  {{ 0, 1, 2,-2, 2},    -1.88, 0.00},
  {{ 0, 0, 2,-2, 0},     0.25, 0.00},
  {{ 0, 0, 2,-2, 1},     1.17, 0.00},
  {{ 0, 0, 2,-2, 2},   -48.84, 0.11},
  {{ 0, 2, 0, 0, 0},    -0.19, 0.00},
  {{ 2, 0, 0,-2,-1},     0.05, 0.00},
  {{ 2, 0, 0,-2, 0},    -0.55, 0.00},
  {{ 2, 0, 0,-2, 1},     0.04, 0.00},
  {{ 0,-1, 2,-2, 1},    -0.05, 0.00},
  {{ 0, 1, 0, 0,-1},     0.09, 0.00},
  {{ 0,-1, 2,-2, 2},     0.83, 0.00},
  {{ 0, 1, 0, 0, 0},   -15.55, 0.02},
  {{ 0, 1, 0, 0, 1},    -0.14, 0.00},
  {{ 1, 0, 0,-1, 0},     0.03, 0.00},
  {{ 2, 0,-2, 0, 0},    -0.14, 0.00},
  {{-2, 0, 2, 0, 1},     0.42, 0.00},
  {{-1, 1, 0, 1, 0},     0.04, 0.00},
  {{ 0, 0, 0, 0, 2},     7.90, 0.00},
  {{ 0, 0, 0, 0, 1}, -1637.68,-0.10},
  //  !
  //  ! Note: The last line contains corrected term for DUT1: "-0.10"
  //  !       Previous versions contained misprint: "0.10"
};
const int numOfRecs_Ut1s83 = sizeof(ut1Ttable_Ut1s83)/sizeof(SgUt1TidalTableEntry_Clipped);



/*=====================================================================================================*/
